<?php

namespace Karneaud\LavaliteKarneaudCargo\Http\Controllers;

use App\Http\Controllers\Controller as BaseController;
use Karneaud\LavaliteKarneaudCargo\Http\Requests\CourierRequest;
use Karneaud\LavaliteKarneaudCargo\Models\Courier;

/**
 * Admin web controller class.
 */
class CourierWorkflowController extends BaseController
{

    /**
     * Workflow controller function for courier.
     *
     * @param Model   $courier
     * @param step    next step for the workflow.
     *
     * @return Response
     */

    public function putWorkflow(CourierRequest $request, Courier $courier, $step)
    {

        try {

            $courier->updateWorkflow($step);

            return response()->json([
                'message'  => trans('messages.success.changed', ['Module' => trans('lavalite-karneaud-cargo::courier.name'), 'status' => trans("app.{$step}")]),
                'code'     => 204,
                'redirect' => trans_url('/admin/courier/courier/' . $courier->getRouteKey()),
            ], 201);

        } catch (Exception $e) {

            return response()->json([
                'message'  => $e->getMessage(),
                'code'     => 400,
                'redirect' => trans_url('/admin/courier/courier/' . $courier->getRouteKey()),
            ], 400);

        }

    }

    /**
     * Workflow controller function for courier.
     *
     * @param Model   $courier
     * @param step    next step for the workflow.
     * @param user    encrypted user id.
     *
     * @return Response
     */

    public function getWorkflow(Courier $courier, $step, $user)
    {
        try {
            $user_id = decrypt($user);

            Auth::onceUsingId($user_id);

            $courier->updateWorkflow($step);

            $data = [
                'message' => trans('messages.success.changed', ['Module' => trans('lavalite-karneaud-cargo::courier.name'), 'status' => trans("app.{$step}")]),
                'status'  => 'success',
                'step'    => trans("app.{$step}"),
            ];

            return $this->theme->layout('blank')->of('lavalite-karneaud-cargo::admin.courier.message', $data)->render();

        } catch (ValidationException $e) {

            $data = [
                'message' => '<b>' . $e->getMessage() . '</b> <br /><br />' . implode('<br />', $e->validator->errors()->all()),
                'status'  => 'error',
                'step'    => trans("app.{$step}"),
            ];

            return $this->theme->layout('blank')->of('lavalite-karneaud-cargo::admin.courier.message', $data)->render();

        } catch (Exception $e) {

            $data = [
                'message' => '<b>' . $e->getMessage() . '</b>',
                'status'  => 'error',
                'step'    => trans("app.{$step}"),
            ];

            return $this->theme->layout('blank')->of('lavalite-karneaud-cargo::admin.courier.message', $data)->render();

        }

    }
}
