<?php

namespace Karneaud\LavaliteKarneaudCargo\Policies;

use Litepie\User\Contracts\UserPolicy;
use Karneaud\LavaliteKarneaudCargo\Models\Courier;

class CourierPolicy
{

    /**
     * Determine if the given user can view the courier.
     *
     * @param UserPolicy $user
     * @param Courier $courier
     *
     * @return bool
     */
    public function view(UserPolicy $user, Courier $courier)
    {
        if ($user->canDo('lavalite-karneaud-cargo.courier.view') && $user->isAdmin()) {
            return true;
        }

        return $courier->user_id == user_id() && $courier->user_type == user_type();
    }

    /**
     * Determine if the given user can create a courier.
     *
     * @param UserPolicy $user
     * @param Courier $courier
     *
     * @return bool
     */
    public function create(UserPolicy $user)
    {
        return  $user->canDo('lavalite-karneaud-cargo.courier.create');
    }

    /**
     * Determine if the given user can update the given courier.
     *
     * @param UserPolicy $user
     * @param Courier $courier
     *
     * @return bool
     */
    public function update(UserPolicy $user, Courier $courier)
    {
        if ($user->canDo('lavalite-karneaud-cargo.courier.edit') && $user->isAdmin()) {
            return true;
        }

        return $courier->user_id == user_id() && $courier->user_type == user_type();
    }

    /**
     * Determine if the given user can delete the given courier.
     *
     * @param UserPolicy $user
     * @param Courier $courier
     *
     * @return bool
     */
    public function destroy(UserPolicy $user, Courier $courier)
    {
        return $courier->user_id == user_id() && $courier->user_type == user_type();
    }

    /**
     * Determine if the given user can verify the given courier.
     *
     * @param UserPolicy $user
     * @param Courier $courier
     *
     * @return bool
     */
    public function verify(UserPolicy $user, Courier $courier)
    {
        if ($user->canDo('lavalite-karneaud-cargo.courier.verify')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the given user can approve the given courier.
     *
     * @param UserPolicy $user
     * @param Courier $courier
     *
     * @return bool
     */
    public function approve(UserPolicy $user, Courier $courier)
    {
        if ($user->canDo('lavalite-karneaud-cargo.courier.approve')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the user can perform a given action ve.
     *
     * @param [type] $user    [description]
     * @param [type] $ability [description]
     *
     * @return [type] [description]
     */
    public function before($user, $ability)
    {
        if ($user->isSuperuser()) {
            return true;
        }
    }
}
