<?php

namespace Karneaud\LavaliteKarneaudCargo\Workflow;

use Exception;
use Litepie\Workflow\Exceptions\WorkflowActionNotPerformedException;

use Karneaud\LavaliteKarneaudCargo\Models\Courier;

class CourierAction
{
    /**
     * Perform the complete action.
     *
     * @param Courier $courier
     *
     * @return Courier
     */
    public function complete(Courier $courier)
    {
        try {
            $courier->status = 'complete';
            return $courier->save();
        } catch (Exception $e) {
            throw new WorkflowActionNotPerformedException();
        }
    }

    /**
     * Perform the verify action.
     *
     * @param Courier $courier
     *
     * @return Courier
     */public function verify(Courier $courier)
    {
        try {
            $courier->status = 'verify';
            return $courier->save();
        } catch (Exception $e) {
            throw new WorkflowActionNotPerformedException();
        }
    }

    /**
     * Perform the approve action.
     *
     * @param Courier $courier
     *
     * @return Courier
     */public function approve(Courier $courier)
    {
        try {
            $courier->status = 'approve';
            return $courier->save();
        } catch (Exception $e) {
            throw new WorkflowActionNotPerformedException();
        }
    }

    /**
     * Perform the publish action.
     *
     * @param Courier $courier
     *
     * @return Courier
     */public function publish(Courier $courier)
    {
        try {
            $courier->status = 'publish';
            return $courier->save();
        } catch (Exception $e) {
            throw new WorkflowActionNotPerformedException();
        }
    }

    /**
     * Perform the archive action.
     *
     * @param Courier $courier
     *
     * @return Courier
     */
    public function archive(Courier $courier)
    {
        try {
            $courier->status = 'archive';
            return $courier->save();
        } catch (Exception $e) {
            throw new WorkflowActionNotPerformedException();
        }
    }

    /**
     * Perform the unpublish action.
     *
     * @param Courier $courier
     *
     * @return Courier
     */
    public function unpublish(Courier $courier)
    {
        try {
            $courier->status = 'unpublish';
            return $courier->save();
        } catch (Exception $e) {
            throw new WorkflowActionNotPerformedException();
        }
    }
}
