<?php

namespace Karneaud\LavaliteKarneaudCargo\Workflow;

use Karneaud\LavaliteKarneaudCargo\Models\Courier;
use Validator;

class CourierValidator
{

    /**
     * Determine if the given courier is valid for complete status.
     *
     * @param Courier $courier
     *
     * @return bool / Validator
     */
    public function complete(Courier $courier)
    {
        return Validator::make($courier->toArray(), [
            'title' => 'required|min:15',
        ]);
    }

    /**
     * Determine if the given courier is valid for verify status.
     *
     * @param Courier $courier
     *
     * @return bool / Validator
     */
    public function verify(Courier $courier)
    {
        return Validator::make($courier->toArray(), [
            'title'  => 'required|min:15',
            'status' => 'in:complete',
        ]);
    }

    /**
     * Determine if the given courier is valid for approve status.
     *
     * @param Courier $courier
     *
     * @return bool / Validator
     */
    public function approve(Courier $courier)
    {
        return Validator::make($courier->toArray(), [
            'title'  => 'required|min:15',
            'status' => 'in:verify',
        ]);

    }

    /**
     * Determine if the given courier is valid for publish status.
     *
     * @param Courier $courier
     *
     * @return bool / Validator
     */
    public function publish(Courier $courier)
    {
        return Validator::make($courier->toArray(), [
            'title'       => 'required|min:15',
            'description' => 'required|min:50',
            'status'      => 'in:approve,archive,unpublish',
        ]);

    }

    /**
     * Determine if the given courier is valid for archive status.
     *
     * @param Courier $courier
     *
     * @return bool / Validator
     */
    public function archive(Courier $courier)
    {
        return Validator::make($courier->toArray(), [
            'title'       => 'required|min:15',
            'description' => 'required|min:50',
            'status'      => 'in:approve,publish,unpublish',
        ]);

    }

    /**
     * Determine if the given courier is valid for unpublish status.
     *
     * @param Courier $courier
     *
     * @return bool / Validator
     */
    public function unpublish(Courier $courier)
    {
        return Validator::make($courier->toArray(), [
            'title'       => 'required|min:15',
            'description' => 'required|min:50',
            'status'      => 'in:publish',
        ]);

    }
}
